# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IntegrationCustomNamespacesPerServiceArgs',
    'IntegrationCustomNamespacesPerServiceArgsDict',
    'IntegrationResourceFilterRuleArgs',
    'IntegrationResourceFilterRuleArgsDict',
]

MYPY = False

if not MYPY:
    class IntegrationCustomNamespacesPerServiceArgsDict(TypedDict):
        namespaces: pulumi.Input[Sequence[pulumi.Input[str]]]
        """
        The additional namespaces.
        """
        service: pulumi.Input[str]
        """
        The name of the service.
        """
elif False:
    IntegrationCustomNamespacesPerServiceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationCustomNamespacesPerServiceArgs:
    def __init__(__self__, *,
                 namespaces: pulumi.Input[Sequence[pulumi.Input[str]]],
                 service: pulumi.Input[str]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] namespaces: The additional namespaces.
        :param pulumi.Input[str] service: The name of the service.
        """
        pulumi.set(__self__, "namespaces", namespaces)
        pulumi.set(__self__, "service", service)

    @property
    @pulumi.getter
    def namespaces(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The additional namespaces.
        """
        return pulumi.get(self, "namespaces")

    @namespaces.setter
    def namespaces(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "namespaces", value)

    @property
    @pulumi.getter
    def service(self) -> pulumi.Input[str]:
        """
        The name of the service.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: pulumi.Input[str]):
        pulumi.set(self, "service", value)


if not MYPY:
    class IntegrationResourceFilterRuleArgsDict(TypedDict):
        filter_source: pulumi.Input[str]
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the resource associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function. The source of each filter rule must be in the form filter('key', 'value'). You can join multiple filter statements using the and and or operators. Referenced keys are limited to tags and must start with the azure_tag_ prefix.
        """
elif False:
    IntegrationResourceFilterRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationResourceFilterRuleArgs:
    def __init__(__self__, *,
                 filter_source: pulumi.Input[str]):
        """
        :param pulumi.Input[str] filter_source: Expression that selects the data that Splunk Observability Cloud should sync for the resource associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function. The source of each filter rule must be in the form filter('key', 'value'). You can join multiple filter statements using the and and or operators. Referenced keys are limited to tags and must start with the azure_tag_ prefix.
        """
        pulumi.set(__self__, "filter_source", filter_source)

    @property
    @pulumi.getter(name="filterSource")
    def filter_source(self) -> pulumi.Input[str]:
        """
        Expression that selects the data that Splunk Observability Cloud should sync for the resource associated with this sync rule. The expression uses the syntax defined for the SignalFlow `filter()` function. The source of each filter rule must be in the form filter('key', 'value'). You can join multiple filter statements using the and and or operators. Referenced keys are limited to tags and must start with the azure_tag_ prefix.
        """
        return pulumi.get(self, "filter_source")

    @filter_source.setter
    def filter_source(self, value: pulumi.Input[str]):
        pulumi.set(self, "filter_source", value)


