# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

apiUrl: Optional[str]
"""
API URL for your Splunk Observability Cloud org, may include a realm
"""

authToken: Optional[str]
"""
Splunk Observability Cloud auth token
"""

customAppUrl: Optional[str]
"""
Application URL for your Splunk Observability Cloud org, often customized for organizations using SSO
"""

email: Optional[str]
"""
Used to create a session token instead of an API token, it requires the account to be configured to login with Email and
Password
"""

organizationId: Optional[str]
"""
Required if the user is configured to be part of multiple organizations
"""

password: Optional[str]
"""
Used to create a session token instead of an API token, it requires the account to be configured to login with Email and
Password
"""

retryMaxAttempts: Optional[int]
"""
Max retries for a single HTTP call. Defaults to 4
"""

retryWaitMaxSeconds: Optional[int]
"""
Maximum retry wait for a single HTTP call in seconds. Defaults to 30
"""

retryWaitMinSeconds: Optional[int]
"""
Minimum retry wait for a single HTTP call in seconds. Defaults to 1
"""

timeoutSeconds: Optional[int]
"""
Timeout duration for a single HTTP call in seconds. Defaults to 120
"""

