# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IntegrationProjectServiceKeyArgs',
    'IntegrationProjectServiceKeyArgsDict',
    'IntegrationProjectWifConfigArgs',
    'IntegrationProjectWifConfigArgsDict',
]

MYPY = False

if not MYPY:
    class IntegrationProjectServiceKeyArgsDict(TypedDict):
        project_id: pulumi.Input[str]
        project_key: pulumi.Input[str]
elif False:
    IntegrationProjectServiceKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationProjectServiceKeyArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 project_key: pulumi.Input[str]):
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "project_key", project_key)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="projectKey")
    def project_key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "project_key")

    @project_key.setter
    def project_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_key", value)


if not MYPY:
    class IntegrationProjectWifConfigArgsDict(TypedDict):
        project_id: pulumi.Input[str]
        wif_config: pulumi.Input[str]
elif False:
    IntegrationProjectWifConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IntegrationProjectWifConfigArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 wif_config: pulumi.Input[str]):
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "wif_config", wif_config)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="wifConfig")
    def wif_config(self) -> pulumi.Input[str]:
        return pulumi.get(self, "wif_config")

    @wif_config.setter
    def wif_config(self, value: pulumi.Input[str]):
        pulumi.set(self, "wif_config", value)


