# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ViewColumn',
    'ViewSortOption',
]

@pulumi.output_type
class ViewColumn(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: Name of the log view.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the log view.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class ViewSortOption(dict):
    def __init__(__self__, *,
                 descending: bool,
                 field: str):
        """
        :param bool descending: Name of the column
        :param str field: Name of the column
        """
        pulumi.set(__self__, "descending", descending)
        pulumi.set(__self__, "field", field)

    @property
    @pulumi.getter
    def descending(self) -> bool:
        """
        Name of the column
        """
        return pulumi.get(self, "descending")

    @property
    @pulumi.getter
    def field(self) -> str:
        """
        Name of the column
        """
        return pulumi.get(self, "field")


